@@ -1,5 +1,6 @@
 /* Procman - tree view
  * Copyright (C) 2001 Kevin Vandersloot
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -71,4 +72,7 @@ void            proctable_set_columns_order(GtkTreeView *treeview, GSList *order
 
 char*           make_loadavg_string(void);
 
+void            get_last_selected (GtkTreeModel *model, GtkTreePath *path,
+                                   GtkTreeIter *iter, gpointer data);
+
 #endif /* _PROCMAN_PROCTABLE_H_ */
